@@ -166,11 +166,7 @@ int main(int argc, char** argv)
 
         if (!parser.value(extOpt).isEmpty()) {
             const auto extNames = parser.value(extOpt).split(QLatin1Char(';'),
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-                                                             QString::SkipEmptyParts);
-#else
                                                              Qt::SkipEmptyParts);
-#endif
             std::vector<Extractor> exts;
             exts.reserve(extNames.size());
             for (const auto &name : extNames) {
